/* 
 * Demonstration program for the MCF5272 port.
 * Written by Jimmie Alam and Brian Birtles. Based on demonstration progams of
 * the PC and AVR ports.
 *
 * NOTE: Although the tests we have run pass, they fail if the check interval is
 * not very long. We have been unsuccessful in debugging exactly why this is
 * caused but for now we have disabled all but the integer tests as otherwise
 * the timeout must be incredibly long in order for the tests to pass.
 */ 

#include <stdio.h>

/* Scheduler include files. */
#include "projdefs.h"
#include "portable.h"
#include "task.h"

/* Demo file headers. */
#include "PollQ.h"
#include "integer.h"
#include "print.h"
#include "BlockQ.h"
#include "death.h"
#include "fileIO.h"
#include "semtest.h"
#include "dynamic.h"

/* Priority definitions for most of the tasks in the demo application.  Some
tasks just use the idle priority. */
#define mainCREATOR_TASK_PRIORITY	( tskIDLE_PRIORITY + ( unsigned portCHAR ) 3 )
#define mainPRINT_TASK_PRIORITY		( tskIDLE_PRIORITY + ( unsigned portCHAR ) 4 )
#define mainQUEUE_POLL_PRIORITY		( tskIDLE_PRIORITY + ( unsigned portCHAR ) 2 )
#define mainQUEUE_BLOCK_PRIORITY	( tskIDLE_PRIORITY + ( unsigned portCHAR ) 3 )
#define mainSEMAPHORE_TASK_PRIORITY	( tskIDLE_PRIORITY + ( unsigned portCHAR ) 1 )

#define mainPRINT_STACK_SIZE		( ( unsigned portSHORT ) 512 )
#define mainDEBUG_LOG_BUFFER_SIZE	( ( unsigned portSHORT ) 20480 )
#define mainCHECK_PERIOD			( ( portTickType ) 100000 / portTICKS_PER_MS )

/* Task function for the "Print" task as described at the top of the file. */
static void vErrorChecks( void *pvParameters );

/* Function that checks the unique count of all the other tasks as described at
the top of the file. */
static void prvCheckOtherTasksAreStillRunning( void );

/* Constant definition used to turn on/off the pre-emptive scheduler. */
static const portSHORT sUsingPreemption = pdTRUE;

portSHORT main( void )
{
	/* Initialise hardware and utilities. */
	vPrintInitialise();
	
	/* CREATE ALL THE DEMO APPLICATION TASKS. */
	vStartIntegerMathTasks( tskIDLE_PRIORITY );
	/* Currently we have to make the check interval reaaally long if we want the
	 * other tests to pass. */
	/*
	vStartPolledQueueTasks( mainQUEUE_POLL_PRIORITY );
	vStartBlockingQueueTasks( mainQUEUE_BLOCK_PRIORITY );
	vStartSemaphoreTasks( mainSEMAPHORE_TASK_PRIORITY );
	vStartDynamicPriorityTasks();
	*/

	/* Create the "Print" task as described at the top of the file. */
	sTaskCreate( vErrorChecks, "Print", mainPRINT_STACK_SIZE, NULL,
				mainPRINT_TASK_PRIORITY, NULL );

	/* This task has to be created last as it keeps account of the number of
	 * tasks it expects to see running. */
	/*
	vCreateSuicidalTasks( mainCREATOR_TASK_PRIORITY );
	*/
	
	/* Set the scheduler running.  This function will not return unless a task
	calls vTaskEndScheduler(). */
	vTaskStartScheduler( sUsingPreemption );

	return 1;
}
/*-----------------------------------------------------------*/

static void vErrorChecks( void *pvParameters )
{
( void ) pvParameters;

	for( ;; )
	{
		vTaskDelay ( mainCHECK_PERIOD );
		/* Check the other tasks are still running, just in case. */
		prvCheckOtherTasksAreStillRunning();
	}
}
/*-----------------------------------------------------------*/

static void prvCheckOtherTasksAreStillRunning( void )
{
portSHORT sErrorHasOccurred = pdFALSE;

	if( sAreIntegerMathsTaskStillRunning() != pdTRUE )
	{
		vDisplayMessage( "Maths task count unchanged!\r\n" );
		sErrorHasOccurred = pdTRUE;
	}

/*
	if( sAreBlockingQueuesStillRunning() != pdTRUE )
	{
		vDisplayMessage( "Blocking queues count unchanged!\r\n" );
		sErrorHasOccurred = pdTRUE;
	}

	if( sArePollingQueuesStillRunning() != pdTRUE )
	{
		vDisplayMessage( "Polling queue count unchanged!\r\n" );
		sErrorHasOccurred = pdTRUE;
	}

	if( sIsCreateTaskStillRunning() != pdTRUE )
	{
		vDisplayMessage( "Incorrect number of tasks running!\r\n" );
		sErrorHasOccurred = pdTRUE;
	}

	if( sAreSemaphoreTasksStillRunning() != pdTRUE )
	{
		vDisplayMessage( "Semaphore take count unchanged!\r\n" );
		sErrorHasOccurred = pdTRUE;
	}

	if( sAreDynamicPriorityTasksStillRunning() != pdTRUE )
	{
		vDisplayMessage( "Dynamic priority count unchanged!\r\n" );
		sErrorHasOccurred = pdTRUE;
	}
	*/

	if( sErrorHasOccurred == pdFALSE )
	{
		vDisplayMessage( "OK " );
	}
}

