/* 
 * Written by Vladimir Lasky, Faculty of Engineering, University of Technology,
 * Sydney. Used by permission.
 *
 * Exception stack frame and status register defines added by Brian Birtles.
 * 
 * Motorola MCF5272 SIM/Peripheral register configuration details.
 * Incomplete - designed to support timers only
*/

typedef unsigned char byte;
typedef unsigned short word;
typedef unsigned long lword;

#define VBR 0
#define MBAR 0x10000000

#define ICR1 (*(lword*)(MBAR + 0x020))
#define ICR2 (*(lword*)(MBAR + 0x024))
#define ICR3 (*(lword*)(MBAR + 0x028))
#define ICR4 (*(lword*)(MBAR + 0x02C))

#define ICR1_INT1PI (0x1 << 31)
#define ICR1_INT1PL(a) ((a & 0x7) << 28)
#define ICR1_INT2PI (0x1 << 27)
#define ICR1_INT2PL(a) ((a & 0x7) << 24)
#define ICR1_INT3PI (0x1 << 23)
#define ICR1_INT3PL(a) ((a & 0x7) << 20)
#define ICR1_INT4PI (0x1 << 19)
#define ICR1_INT4PL(a) ((a & 0x7) << 16)
#define ICR1_TMR0PI (0x1 << 15)
#define ICR1_TMR0PL(a) ((a & 0x7) << 12)
#define ICR1_TMR1PI (0x1 << 11)
#define ICR1_TMR1PL(a) ((a & 0x7) << 8)
#define ICR1_TMR2PI (0x1 << 7)
#define ICR1_TMR2PL(a) ((a & 0x7) << 4)
#define ICR1_TMR3PI (0x1 << 3)
#define ICR1_TMR3PL(a) ((a & 0x7) << 0)

#define ISR (*(lword*)(MBAR + 0x030))

#define ISR_INT1 (0x1 << 31)
#define ISR_INT2 (0x1 << 30)
#define ISR_INT3 (0x1 << 29)
#define ISR_INT4 (0x1 << 28)
#define ISR_TMR0 (0x1 << 27)
#define ISR_TMR1 (0x1 << 26)
#define ISR_TMR2 (0x1 << 25)
#define ISR_TMR3 (0x1 << 24)

#define PITR (*(lword*)(MBAR + 0x34))

#define PIWR (*(lword*)(MBAR + 0x38))
#define PIWR_INT1 (0x1 << 31)
#define PIWR_INT2 (0x1 << 30)
#define PIWR_INT3 (0x1 << 29)
#define PIWR_INT4 (0x1 << 28)
#define PIWR_TMR0 (0x1 << 27)
#define PIWR_TMR1 (0x1 << 26)
#define PIWR_TMR2 (0x1 << 25)
#define PIWR_TMR3 (0x1 << 24)

#define PIVR (*(byte*)(MBAR + 0x3f))
#define PIVR_DEFAULT (0x40)

#define VECTOR_USER_SPURIOUS 64
#define VECTOR_TMR0 69
#define VECTOR_TMR1 70
#define VECTOR_TMR2 71
#define VECTOR_TMR3 72

#define TMR0 (*(word*)(MBAR + 0x200))
#define TMR1 (*(word*)(MBAR + 0x220))
#define TMR2 (*(word*)(MBAR + 0x240))
#define TMR3 (*(word*)(MBAR + 0x260))

#define TMRX_PRESCALER(a) ((a&0xff) << 8)
#define TMRX_CE(a) ((a&0x3) << 6)
#define TMRX_OM (0x1 << 5)
#define TMRX_ORI (0x1 << 4)
#define TMRX_FRR (0x1 << 3)
#define TMRX_CLK(a) ((a&0x3) << 1)
#define TMRX_RST 0x1

#define TRR0 (*(word*)(MBAR + 0x204))
#define TRR1 (*(word*)(MBAR + 0x224))
#define TRR2 (*(word*)(MBAR + 0x244))
#define TRR3 (*(word*)(MBAR + 0x264))

#define TCAP0 (*(word*)(MBAR + 0x208))
#define TCAP1 (*(word*)(MBAR + 0x228))
#define TCAP2 (*(word*)(MBAR + 0x248))
#define TCAP3 (*(word*)(MBAR + 0x268))

#define TCN0 (*(word*)(MBAR + 0x20c))
#define TCN1 (*(word*)(MBAR + 0x22c))
#define TCN2 (*(word*)(MBAR + 0x24c))
#define TCN3 (*(word*)(MBAR + 0x26c))

#define TER0 (*(word*)(MBAR + 0x210))
#define TER1 (*(word*)(MBAR + 0x220))
#define TER2 (*(word*)(MBAR + 0x230))
#define TER3 (*(word*)(MBAR + 0x240))

#define TERX_REF (0x2)
#define TERX_CAP (0x1)

#define EXSF_FORMAT(a) (a << 28)
#define EXSF_FS(a) ((a&12 << 26)|(a&3 << 16))
#define EXSF_VECTOR(a) (a << 18)

#define STATUS_T (0x1 << 15)
#define STATUS_S (0x1 << 13)
#define STATUS_M (0x1 << 12)
#define STATUS_I(a) (a << 8)

